@@ -4,7 +4,7 @@ from fabric.colors import *
 from fabric.state import env
 from ground_soil.fabric import virtual_env
 from beanstalk.decorators import beanstalk_role
-from beanstalk.titles import action_title
+from beanstalk.console.titles import action_title
 
 
 def action(command, work_directory=None, venv=None, chdir=None):
@@ -12,6 +12,12 @@ def action(command, work_directory=None, venv=None, chdir=None):
     remote = env.in_remote
     exec_command = run if remote else local
 
+    if remote:
+        command = 'bsjack server.run_app_command:{name},"{command}"'.format(
+            name=env.project_name,
+            command=command.replace('"', '\\"')
+        )
+
     if remote and chdir in ('base', 'source', 'logs'):
         work_directory = env.remote_app_info['path'][chdir]
         venv = env.remote_app_info['path']['venv']
