@@ -243,12 +243,13 @@ def deploy_remote_core():
 
     # Find Jack first
     with settings(hide('everything'), warn_only=True):
-        if run('which bsjack').return_code != 0:
+        bs_version_result = run('bsjack info.version:USE_JSON=True --hide=status')
+        if bs_version_result.failed:
             abort(
                 red('Hey! I cannot find Jack at ') + red(host_name, bold=True) + red('. ') +
                 'Please setup beanstalk-stack on this server first.'
             )
-        remote_bs_version = json.loads(run('bsjack info.version:USE_JSON=True --hide=status'))
+        remote_bs_version = json.loads(bs_version_result)
         if beanstalk_version_tuple != tuple(remote_bs_version['list']):
             abort(red('Hey! Jack at the remote is not the same as me. He\'s {0}. But I\'m {1}.').format(
                 remote_bs_version['string'], beanstalk_version_string))
