@@ -533,3 +533,22 @@ def add_user(tmp_key_path, clean_tmp_key=False):
         local('rm -rf {path}'.format(path=tmp_key_path))
 
     print green('User added.')
+
+
+@task
+@beanstalk_role('server')
+def run_app_command(project_name, command, location='source'):
+    """Run a remote command
+    """
+    print command
+#    if location == 'base':
+#        path = project_base_path(project_name)
+#    elif location == 'logs':
+#        path = project_logs_path(project_name)
+#    else:
+#        path = project_source_path(project_name)
+#
+#    venv_path = project_venv_path(project_name)
+#
+#    with settings(lcd(path), virtual_env(venv_path)):
+#        local(command)
